searchData={"items":[{"type":"module","title":"SimpleFilters","doc":"Macros for applying filters to ecto queries.","ref":"SimpleFilters.html"},{"type":"function","title":"SimpleFilters.cut_operator/1","doc":"Cuts the operator part from a string, so that it can be put in a query.","ref":"SimpleFilters.html#cut_operator/1"},{"type":"macro","title":"SimpleFilters.filter_boolean/3","doc":"Filters for a boolean a value.","ref":"SimpleFilters.html#filter_boolean/3"},{"type":"macro","title":"SimpleFilters.filter_date/4","doc":"","ref":"SimpleFilters.html#filter_date/4"},{"type":"macro","title":"SimpleFilters.filter_like/4","doc":"Filters for a string using ilike.","ref":"SimpleFilters.html#filter_like/4"},{"type":"macro","title":"SimpleFilters.filter_list/4","doc":"","ref":"SimpleFilters.html#filter_list/4"},{"type":"macro","title":"SimpleFilters.filter_range/3","doc":"","ref":"SimpleFilters.html#filter_range/3"},{"type":"macro","title":"SimpleFilters.filter_string/4","doc":"","ref":"SimpleFilters.html#filter_string/4"},{"type":"function","title":"SimpleFilters.get_column/2","doc":"Gets the column from opts or name","ref":"SimpleFilters.html#get_column/2"},{"type":"function","title":"SimpleFilters.parse_integer/1","doc":"Parses a value to an integer, converting it when necessary.","ref":"SimpleFilters.html#parse_integer/1"},{"type":"extras","title":"Simple filters","doc":"# Simple filters\n\nSimple filters for Ecto from query params.","ref":"readme.html"},{"type":"extras","title":"Usage - Simple filters","doc":"```elixir\ndef MySchema do\n  import SimpleFilters\n\n  schema \"myschema\" do\n    # your fields\n  end\n\n  filter_boolean(\"enabled\", [m], m)\n  filter_range(\"age\", [m], m)\n  filter_string(\"name\", [m], m)\n  filter_like(\"description\", [m], m)\n  filter_string(\"foreign\", [n: n], n)\n  filter_list(\"color\", [m], m)\n\n  def filter_by_params(query, params) do\n    # plug the filters where ever you are handling where statements\n    # I find it convenient to put them in one function\n    query\n    |> filter_by_enabled(params)\n    |> filter_by_age(params)\n    |> filter_by_name(params)\n    |> filter_by_description(params)\n    |> filter_by_foreign(params)\n    |> filter_by_color(params)\n  end\nend\n```\n\nNow you can query `MySchema` like so:\n\n```elixir\n MySchema \n |> MySchema.filter_by_params(params)\n```\n\nSupported queries for boolean filters:\n\n```elixir\n%{\"field\" => \"true\"|\"false\"|true|false}\n```\n\nSupported queries for range filters:\n\n```elixir\n%{\"from_field\" => 0, \"to_field\" => 100}\n\n\n# Strings will be converted to integers,\n# or 0 when that can't be done\n%{\"from_field\" => \"15\", \"to_field\" => \"weird\"}\n\n# Works with only one side too:\n%{\"from_field\" => 55}\n%{\"to_field\" => 25}\n```\n\nSupported queries for string filters:\n\n```elixir\n%{\"name\" => \"some name\"}\n\n# Supports != by prefixing !\n%{\"name\" => \"!some name\"}\n```\n\nSupported queries for list filters:\n\n```elixir\n%{\"color\" => \"red\"}\n\n# To get multiple colors:\n%{\"color\" => [\"red\", \"blue\"]}\n```\n\nSupported queries for like filters:\n\n```elixir\n# Results in an ilike(:description, \"%hello world%\") where\n%{\"description\" => \"hello world\"} \n\n# Supports != by prefixing !\n%{\"description\" => \"!hello world\"}\n\n# Supports matching only at the end with ^\n# i.e. ilike(:description, \"hello world%\")\n%{\"description\" => \"^hello world\"}\n```","ref":"readme.html#usage"}],"content_type":"text/markdown"}